@@ -11,3 +11,8 @@ def update_all_feeds():
     for feed in Feed.objects.all():
         feed._update_feed()
 
+
+@task(name='send_digest')
+def send_digest():
+    import digest
+    digest.send_digest()
\ No newline at end of file
